whatsthedamage package
======================

.. automodule:: whatsthedamage
   :members:
   :show-inheritance:
   :undoc-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   whatsthedamage.api
   whatsthedamage.config
   whatsthedamage.controllers
   whatsthedamage.models
   whatsthedamage.services
   whatsthedamage.utils
   whatsthedamage.view

Submodules
----------

whatsthedamage.app module
-------------------------

.. automodule:: whatsthedamage.app
   :members:
   :show-inheritance:
   :undoc-members:

whatsthedamage.cli\_app module
------------------------------

.. automodule:: whatsthedamage.cli_app
   :members:
   :show-inheritance:
   :undoc-members:
